PSI (SINQ)
----------

CCU4 tutorial example
.....................

.. automodule:: frappy_psi.ccu4
    :show-inheritance:
    :members:


PPMS
....

.. automodule:: frappy_psi.ppms
    :show-inheritance:
    :members:

LakeShore 370
.............

Calibrated sensors and control loop not yet supported.

.. automodule:: frappy_psi.ls370res
    :show-inheritance:
    :members:

Bath Thermostat Thermofisher
............................

.. automodule:: frappy_psi.thermofisher
    :show-inheritance:
    :members:

